#include "Image.hpp"

#include <stdio.h>
#include <string.h>
#include <fstream>
#include <iostream> // keep this if you prefer to use cout over printf

using namespace std;

Image::Image()
: npixels(0), width(0), height(0)
{}

Image::Image(const char *filename)
    : npixels(0), width(0), height(0)
{
    if (!Read(filename)){
        printf("Image not created");
    }
}

Image::~Image() {
    //delete image_data;
}

bool Image::Read(const char *filename)
{
    // load image file
    QImage image(QString(filename), "JPG");
    if (image.isNull()) {
        return IMAGE_RETURN_FAILURE;
    }
    // convert to 32-bit image where each pixel is a QRgb
    image_data = image.convertToFormat(QImage::Format_RGB32);
    if (image_data.isNull()) {
        return IMAGE_RETURN_FAILURE;
    }

    width = image_data.width();
    height = image_data.height();
    npixels = width * height;

    QImage new_data(500,1000, QImage::Format_RGB32);
    QColor color(50,50,50);
    new_data.setPixel(50, 87, color.rgb());

    return IMAGE_RETURN_SUCCESS;
}


bool Image::Write(const char *filename)
{
    if (image_data.save(QString(filename), "JPG")) {
        return IMAGE_RETURN_SUCCESS;
    } else {
        return IMAGE_RETURN_FAILURE;
    }
}


void Image::BilateralFilter(double rangesigma, double domainsigma)
{
    printf("Must implement BilateralFilter()\n");
}


void Image::BlackAndWhite()
{
    printf("Must implement BlackAndWhite()\n");
}


void Image::Brightness(double factor)
{
    printf("Must implement Brightness()\n");
}


void Image::ChannelExtract(int channel)
{
    printf("Must implement ChannelExtract()\n");
}


void Image::Composite()
{
    printf("Must implement Composite()\n");
}


void Image::Contrast(double factor)
{
    printf("Must implement Contrast()\n");
}


void Image::Crop(int top_left_x, int top_left_y, int crop_width, int crop_height)
{
    printf("Must implement Crop()\n");
}


void Image::Fun(int sampling_method)
{
    printf("Must implement Fun()\n");
}


void Image::Gamma(double factor)
{
    printf("Must implement Gamma()\n");
}


void Image::GaussianBlur(double sigma)
{
    printf("Must implement GaussianBlur()\n");
}


void Image::MedianFilter(int filter_width)
{
    printf("Must implement MedianFilter()\n");
}


void Image::MotionBlur(double sigma)
{
    printf("Must implement MotionBlur()\n");
}


void Image::Nonphotorealism()
{
    printf("Must implement Nonphotorealism()\n");
}


void Image::Rotate(double angle, int sampling_method)
{
    printf("Must implement Rotate()\n");
}


void Image::Saturation(double factor)
{
    printf("Must implement Saturation()\n");
}


void Image::Scale(double sx, double sy, int sampling_method)
{
    printf("Must implement Scale()\n");
}


void Image::Sharpen()
{
    printf("Must implement Sharpen()\n");
}
